/******************************************************************************

   FILE				: peripheral.c

   AUTHOR			: Axiom Manufacturing
						  Spencer Ruggles

	PURPOSE			: Mfg Test for EVB51JM128 board, x427

 ******************************************************************************

  Purpose:

  Mfg Functional Test routine for EVB51JM128 board, x427.

******************************************************************************/

#include "MCF51JM128.h"					// include peripheral declarations 
#include "peripheral.h"					// peripheral function includes 
#include "sci.h"							// SCI function includes
#include "lcd.h"							// LCD function includes


byte LCDstr1[] = "AxiomMfg";			// LCD String 1
byte LCDstr2[] = "51JM128";			// LCD String2


// setup initial conditions for test
void init() {
	SOPT1 = 0x00;							// disable COP watchdog
//	MCGSC |= NVFTRIM_FTRIM;		// get NV FTRIM bit 
//	MCGTRM |= NVMCGTRM;					// get NV Trim value 
	
	// TIMER2 Setup
	TPM2SC_PS = div16;					// load prescalar value
	TPM2MODH = 0xFF;						// timer count high
	TPM2MODL = 0xFF;						// timer count low
  	
  	// Parallel IO Setup
	PTCD |= PTCD_PTCD6_MASK | PTCD_PTCD4_MASK;	// init PTCD[6,4] high
	PTCDD |= PTCD_PTCD6_MASK | PTCD_PTCD4_MASK;	//PTCD[6,4] output

	PTDD |= PTDD_PTDD2_MASK;			// init PTDD2 high
	PTDDD |= PTDD_PTDD2_MASK;			//	PTDD2 output

	PTED |= PTED_PTED3_MASK | PTED_PTED2_MASK;	// init PTED[3:2] high
	PTEDD |= PTEDD_PTEDD3_MASK | PTEDD_PTEDD2_MASK;	// PTED[3:2] output

	PTFD |= PTFDD_PTFDD5_MASK | PTFD_PTFD4_MASK |  PTFD_PTFD1_MASK |PTFD_PTFD0_MASK;	// init PTFD[5,4,1,0] high
	PTFDD |= PTFDD_PTFDD5_MASK | PTFDD_PTFDD4_MASK | PTFDD_PTFDD1_MASK | PTFDD_PTFDD0_MASK;	// PTFD[5,4,1:0] otuput

	PTDPE |= PTDPE_PTDPE5_MASK;		// PTDD5 pull enabled for SW test 
	PTGPE |= PTGD_PTGD0_MASK | PTGD_PTGD1_MASK | PTGD_PTGD2_MASK | PTGD_PTGD3_MASK;
												// PTGD[3:0] pull enabled for SW test
	
}

// delay function
void dly2() {
	TPM2SC_CLKSx = bclk;					// start timer @ busclk rate
	while (!TPM2SC_TOF){					// wait for overflow
		;
	}
	TPM2SC_CLKSx = nclk;					// halt timer
	TPM2SC &= ~TPM2SC_TOF_MASK; 		// clr TOF
}

/*******************************************************************************
ledtest

	display "Press Any Key to Continue" message on COM1 port then blinks
	LEDs 1-8 until key pressed on kb.
	
	INPUT:	port		0=SCI1, 1=SCI2
	OUTPUT:	none
********************************************************************************/
void ledtest() {
	byte n = 0;
	
	PressAnyKey(0);							// send string
	while(SerialReady(0)){					// wait for key press
		for(n=0;n<8;++n) {		  	
			PTCD = 0xFF;						// all leds off
			PTDD = 0xFF;			
			PTED = 0xFF;
			PTFD = 0xFF;
			switch(n) { 						// get current count
				case 0:
					PTED &= ~PTED_PTED2_MASK;	// led1 on
					break;
				case 1:
					PTED &= ~PTED_PTED3_MASK;	// led2 on
					break;
				case 2:
					PTFD &= ~PTFD_PTFD0_MASK;	// led3 on
					break;
				case 3:
					PTFD &= ~PTFD_PTFD1_MASK;	// led4 on
					break;
				case 4:
					PTFD &= ~PTFD_PTFD5_MASK;  // led 5 on
					break;
				case 5:
					PTDD &= ~PTDD_PTDD2_MASK;  // led 6 on
					break;
				case 6:
					PTCD &= ~PTCD_PTCD4_MASK;  // led 7 on
					break;
				case 7:
					PTCD &= ~PTCD_PTCD6_MASK;  // led 8 on
					break;
			}
			dly2();									// wait
		}
	}
}

/*******************************************************************************
swtest

	display "Press Any Key to Continue" message on COM1 port then checks 
	for push-button switch press.  Pressing PBSW lights an LED until kb key pressed
	
	INPUT:	port		0=SCI1, 1=SCI2
	OUTPUT:	none
********************************************************************************/
void swtest() {

	PressAnyKey(0);						// send string
	while(SerialReady(0)) {
		PTED = 0xFF;						// LED1-2 off
		PTFD = 0xFF;						// LED3-4 off
		
		if(!PTGD_PTGD1)
			PTED_PTED2 = 0;				// LED1 on
		if(!PTGD_PTGD2)
			PTED_PTED3 = 0;				// LED2 on
		if(!PTGD_PTGD3)
			PTFD_PTFD0 = 0;				// LED3 on
		if(!PTDD_PTDD5)
			PTFD_PTFD1 = 0;				// LED4 on
	}
}

/*******************************************************************************
BTest

	display "Press Any Key to Continue" message on COM1 port then produces a 
	constant tone on buzzer
	
	INPUT:	none
	OUTPUT:	none
********************************************************************************/
void BTest() {
	
	PressAnyKey(0);						// send string
	while(SerialReady(0)) {
		word count = 0x01FF;				// loop count
		while(count) --count;			// wait 
		PTFD ^= PTFD_PTFD4_MASK;		// toggle PTFD pin
	}
}

/*******************************************************************************
LCDTest

	display "Press Any Key to Continue" message on COM1 port then produces 
	prints a display on LCD panel
	
	INPUT:	none
	OUTPUT:	none
********************************************************************************/
void LCDTest() {
	LCDInit();
	LCDputs(LCDstr1);
	LCDputs(LCDstr2);
}

/*******************************************************************************
CANTest

	toggle LED connected to the CAN port output then display "Press Any Key 
	to Continue" message on COM1 port 
	
	INPUT:	none
	OUTPUT:	none
********************************************************************************/
void CANTest() {
	PTFD|= PTFD_PTFD7_MASK;				// PTFD7 set high
	PTFDD |= PTFDD_PTFDD7_MASK;		// PTFD7 output
	PressAnyKey(0);						// send string
	while(SerialReady(0)) {
		PTFD ^= PTFD_PTFD7_MASK;			// toggle PTFD7
		dly2();								// delay
	}
}